#!/bin/bash
set -e
# Print DataPower log to standard out (all available entires)
dpbuddy tail -lines "-1"
# Tail DataPower log, if domainPatterns matches multiple domains,
# tailLog will consolidate logs from these domains
dpbuddy tail -domainPatterns "dpbuddy-.*, e2e.*"  -lines 100
# You can also change the log format.
# The following template will add transaction ID to the log.
# See User Guide for more details
# You can specify any logTarget configured on the device
dpbuddy tail -logTarget "default-log" -format "{1,date,yyyy-MM-dd HH:mm:ss} |{2}| {4,number,#} | {0}{3}"
# Save all log entries from the device locally
dpbuddy tail -lines "-1" -logFile "\${java.io.tmpdir}/dp.log" -appendTimestamp
# Log the message to the device's system log
dpbuddy log -level info -category all  -message "Hello from DPBuddy"

# Managing log targets
# Create syslog target
dpbuddy syslogTarget -name syslg-trg -remoteHost syslog-server -remotePort 123 -localIdentifier "dp7-qa--test" -localAddress dp-qa -levelInfo "all:info, mgmt:info"

# Create SOAP/HTTP log target
dpbuddy soapLogTarget -name soap-trg -remoteUrl "http://soap-backend" -localAddress dp-qa -levelInfo "all:info, mgmt:info" -disabled

# Create file-based log target
dpbuddy fileLogTarget -name file-trg -fileName log-file -logSize 2048 -rotations 3 -levelInfo "all:info, mgmt:info" -comments "file based log target" -save
# Change logging levels of all targets that start with "syslog"
dpbuddy updateLogLevel -name "syslg.*" -levelInfo "all:notice, mgmt:warn"
# Set the logging level of the default log for the 'all' category
dpbuddy setLogLevel -level INFO
